package com.powerlbs.ubiboatdemo;

import android.Manifest;
import android.app.AlertDialog;
import android.app.Notification;
import android.app.PendingIntent;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Build;
import android.os.Bundle;
import android.provider.Settings;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

import com.alibaba.fastjson.JSON;
import com.powerlbs.ubiboat.sdk.UbiboatManager;
import com.powerlbs.ubiboat.sdk.inf.UbiboatListener;
import com.powerlbs.ubiboat.sdk.req.NearInfoReq;
import com.powerlbs.ubiboat.sdk.resp.BaseUbiboatResp;

import java.util.List;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;
import pub.devrel.easypermissions.AfterPermissionGranted;
import pub.devrel.easypermissions.EasyPermissions;

public class MainActivity extends AppCompatActivity implements View.OnClickListener, EasyPermissions.PermissionCallbacks {
    public static String TAG = MainActivity.class.getSimpleName();
    @BindView(R.id.bt_register)
    Button btRegister;
    @BindView(R.id.bt_unregister)
    Button btUnregister;
    @BindView(R.id.bt_scence)
    Button btScence;
    @BindView(R.id.bt_near)
    Button btNear;
    @BindView(R.id.bt_dis)
    Button btDis;
    @BindView(R.id.tv_result)
    TextView tvResult;

    @BindView(R.id.bt_init)
    Button btInit;
    @BindView(R.id.bt_stop)
    Button btStop;
    @BindView(R.id.bt_destory)
    Button btDestory;

    UbiboatManager ubiboatManager = null;
    Notification notification;
    @BindView(R.id.bt_enableB)
    Button btEnableB;
    @BindView(R.id.bt_unenableB)
    Button btUnenableB;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        ButterKnife.bind(this);
        //设置后台定位
        //android8.0及以上使用NotificationUtils
        if (Build.VERSION.SDK_INT >= 26) {
            NotificationUtils mNotificationUtils = new NotificationUtils(this);
            Notification.Builder builder2 = mNotificationUtils.getAndroidChannelNotification
                    ("适配android 8限制后台功能", "正在后台服务");
            notification = builder2.build();
        } else {
            //获取一个Notification构造器
            Notification.Builder builder = new Notification.Builder(MainActivity.this);
            Intent nfIntent = new Intent(MainActivity.this, MainActivity.class);

            builder.setContentIntent(PendingIntent.
                    getActivity(MainActivity.this, 0, nfIntent, 0)) // 设置PendingIntent
                    .setContentTitle("适配android 8限制后台定位功能") // 设置下拉列表里的标题
                    .setSmallIcon(R.mipmap.ic_launcher) // 设置状态栏内的小图标
                    .setContentText("正在后台服务") // 设置上下文内容
                    .setWhen(System.currentTimeMillis()); // 设置该通知发生的时间

            notification = builder.build(); // 获取构建好的Notification
        }
        notification.defaults = Notification.DEFAULT_SOUND; //设置为默认的声音
    }
UbiboatListener ubiboatListener=new UbiboatListener() {
    @Override
    public void onUbiboatResp(final BaseUbiboatResp var) {
        if (var != null) {
            Log.i(TAG, "resp:" + JSON.toJSONString(var));
            runOnUiThread(new Runnable() {
                @Override
                public void run() {
                    tvResult.setText("resp:" + JSON.toJSONString(var));
                }
            });

        }
    }
};
    @OnClick({R.id.bt_init, R.id.bt_register,R.id.bt_unregister,R.id.bt_enableB,R.id.bt_unenableB, R.id.bt_scence, R.id.bt_dis, R.id.bt_near,
            R.id.bt_stop, R.id.bt_destory})
    @Override
    public void onClick(View view) {
        switch (view.getId()) {
            case R.id.bt_init:
                requestExternalStorage();

                break;
            case R.id.bt_register:
                if (ubiboatManager != null) {
                    ubiboatManager.registerUbiboatListener( ubiboatListener);
                }
                break;
            case R.id.bt_enableB:
                ubiboatManager.enableBackgroundUbiboat(1,notification);
                break;
            case R.id.bt_unenableB:
                ubiboatManager.disableBackgroundUbiboat(true);
                break;
            case R.id.bt_scence:
                ubiboatManager.getScene();
                break;
            case R.id.bt_dis:
                //传入其他设备的id
                ubiboatManager.getDis("指定其他用户的id值");
                break;
            case R.id.bt_near:
                ubiboatManager.getAllPoi(NearInfoReq.Type.ALL);
             ubiboatManager.getNearPoi(1000, NearInfoReq.Type.PERSON);
                break;
            case R.id.bt_unregister:
                if (ubiboatManager != null) {
                    ubiboatManager.unRegisterUbiboatListener(ubiboatListener);
                }
                break;
            case R.id.bt_stop:
                ubiboatManager.stop();
                break;
            case R.id.bt_destory:
                ubiboatManager.destory();
                break;
        }

    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (ubiboatManager != null) {
            ubiboatManager.destory();
        }
    }

    private static final int RC_EXTERNAL_STORAGE = 0x04;//存储权限

    @AfterPermissionGranted(RC_EXTERNAL_STORAGE)
    public void requestExternalStorage() {
        if (EasyPermissions.hasPermissions(this, Manifest.permission.READ_EXTERNAL_STORAGE,
                Manifest.permission.WRITE_EXTERNAL_STORAGE,
                Manifest.permission.ACCESS_FINE_LOCATION,
                Manifest.permission.ACCESS_COARSE_LOCATION)) {
            //泛舟服务对象赋值
            ubiboatManager = UbiboatManager.getInstance(MainActivity.this, "用户id值");

        } else {
            EasyPermissions.requestPermissions(this, "", RC_EXTERNAL_STORAGE,
                    Manifest.permission.READ_EXTERNAL_STORAGE,
                    Manifest.permission.WRITE_EXTERNAL_STORAGE,
                    Manifest.permission.ACCESS_FINE_LOCATION,
                    Manifest.permission.ACCESS_COARSE_LOCATION);
        }
    }


    @Override
    public void onPermissionsGranted(int requestCode, List<String> perms) {

    }

    @Override
    public void onPermissionsDenied(int requestCode, List<String> perms) {

        for (String perm : perms) {
            if (perm.equals(Manifest.permission.READ_EXTERNAL_STORAGE)
                    || perm.equals(Manifest.permission.ACCESS_FINE_LOCATION)
                    || perm.equals(Manifest.permission.ACCESS_COARSE_LOCATION)
                    || perm.equals(Manifest.permission.WRITE_EXTERNAL_STORAGE)) {
                new AlertDialog.Builder(this)
                        .setCancelable(true)
                        .setTitle("温馨提示")
                        .setMessage("需要开启您手机的相关权限，是否现在开启")
                        .setPositiveButton("去开启", new DialogInterface.OnClickListener() {
                            @Override
                            public void onClick(DialogInterface dialog, int which) {
                                startActivity(new Intent(Settings.ACTION_APPLICATION_SETTINGS));
                            }
                        })
                        .setNegativeButton("取消", null).show();
            }
        }
    }

    @Override
    public void onRequestPermissionsResult(int requestCode, @NonNull String[] permissions, @NonNull int[] grantResults) {
        EasyPermissions.onRequestPermissionsResult(requestCode, permissions, grantResults, this);
    }

}
